@@ -70,26 +70,20 @@ def findIssuesFile():
 
     possibleFiles = [*glob.glob("issues*.txt"), *glob.glob("*.bsi")]
     if len(possibleFiles) == 0:
-        die(
-            "Can't find an 'issues*.txt' or '*.bsi' file in this folder. Explicitly pass a filename."
-        )
+        die("Can't find an 'issues*.txt' or '*.bsi' file in this folder. Explicitly pass a filename.")
         return
     if len(possibleFiles) == 1:
         return possibleFiles[0]
 
     # If there are more than one, assume they contain either an index or a YYYYMMDD date,
     # and select the largest such value.
-    possibleFiles = [
-        (extractNumber(fn), fn) for fn in possibleFiles if extractNumber(fn) is not None
-    ]
+    possibleFiles = [(extractNumber(fn), fn) for fn in possibleFiles if extractNumber(fn) is not None]
     if len(possibleFiles) == 1:
         return possibleFiles[0][1]
 
     possibleFiles.sort(reverse=True)
     if len(possibleFiles) == 0 or possibleFiles[0][0] == possibleFiles[1][0]:
-        die(
-            "Can't tell which issues-list file is the most recent. Explicitly pass a filename."
-        )
+        die("Can't tell which issues-list file is the most recent. Explicitly pass a filename.")
         return
     return possibleFiles[0][1]
 
@@ -101,6 +95,7 @@ def extractHeaderInfo(lines, infilename):
     ed = None
     date = None
     cdate = None
+    intro = None
     for line in lines:
         match = re.match(r"(Draft|Title|Status|Date|ED):\s*(.*)", line)
         if match:
@@ -156,6 +151,10 @@ def extractHeaderInfo(lines, infilename):
         die("Missing 'ED' metadata.")
         return
 
+    match = re.search(r"^Intro:\s*(.*(\n^$|\n[ \t]+.*)*)", "".join(lines), re.M)
+    if match:
+        intro = match.group(1)
+
     return {
         "title": title,
         "date": date,
@@ -163,6 +162,7 @@ def extractHeaderInfo(lines, infilename):
         "ed": ed,
         "status": status,
         "url": url,
+        "intro": intro,
     }
 
 
@@ -173,7 +173,14 @@ Title:    CSS Foo Level 3 (Mandatory)
 Date:     YYYY-MM-DD (Optional if can be autodetected from the Draft's URL)
 Status:   CR/FPWD/LCWD/LS/Version/… (Optional if can be autodetected from the Draft's URL)
 ED:       https://url.to.the.editor.s/draft/ (Optional, defaults to a csswg editor's draft if shortname can be infered from the Draft's URL)
+Intro:    <p>Optional markup to be injected into the output document.
+          the intro can continue on multiple lines
+          as long as they're indented.
+
+          <p>Blank lines in the middle are fine.
+
 ... anything else you want here, except 4 dashes ...
+... this will not be included in the output ...
 
 ----
 Issue 1.
@@ -208,7 +215,9 @@ def printHeader(outfile, headerInfo):
 
 <p>Review document: <a href="{url}">{url}</a>
 
-<p>Editor's draft: <a href="{ed}">{ed}</a>
+<p>Editor's draft: <a href="{ed}">{ed}</a></p>
+
+{intro}
 
 <p>The following color coding convention is used for comments:</p>
 
