@@ -9,11 +9,7 @@ def unusedInternalDfns(doc):
     If you don't actually *use* a noexport dfn, that's probably an error.
     In particular, this'll probably help find *untagged* dfns that are defaulting to noexport.
     """
-    noexportDfns = [
-        el
-        for el in findAll(dfnElementsSelector, doc)
-        if el.get("data-noexport") == "by-default"
-    ]
+    noexportDfns = [el for el in findAll(dfnElementsSelector, doc) if el.get("data-noexport") == "by-default"]
 
     def local(el):
         return (
