@@ -6,11 +6,7 @@ from . import steps
 
 class HashMultShorthand:
     def respond(self, match, dom=None):  # pylint: disable=unused-argument
-        return steps.Success(
-            E.a(
-                {"data-link-type": "grammar", "data-lt": "#", "for": ""}, match.group(0)
-            )
-        )
+        return steps.Success(E.a({"data-link-type": "grammar", "data-lt": "#", "for": ""}, match.group(0)))
 
 
 HashMultShorthand.startRe = re.compile(r"#{\s*\d+(\s*,(\s*\d+)?)?\s*}")
@@ -52,6 +48,4 @@ class SimpleTokenShorthand:
         )
 
 
-SimpleTokenShorthand.startRe = re.compile(
-    r"(\?|!|#|\*|\+|\|\||\||&amp;&amp;|&&|,)(?!')"
-)
+SimpleTokenShorthand.startRe = re.compile(r"(\?|!|#|\*|\+|\|\||\||&amp;&amp;|&&|,)(?!')")
