@@ -17,9 +17,7 @@ def update(path, dryRun=False):
 
     if not dryRun:
         try:
-            with open(
-                os.path.join(path, "link-defaults.infotree"), "w", encoding="utf-8"
-            ) as f:
+            with open(os.path.join(path, "link-defaults.infotree"), "w", encoding="utf-8") as f:
                 f.write(data)
         except Exception as e:
             die("Couldn't save link-defaults database to disk.\n{0}", e)
